==> haskell-numbers-3000.2.0.2-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-2FlUHXPIjxkAFaOi5E8DoC
key:                  numbers-3000.2.0.2-2FlUHXPIjxkAFaOi5E8DoC
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  a1418564f9224652b4b64bce21c426ca
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-2FlUHXPIjxkAFaOi5E8DoC
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numbers-3000.2.0.2-76.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-5E9gkrEU6WwLqqPGrSWQf0
key:                  numbers-3000.2.0.2-5E9gkrEU6WwLqqPGrSWQf0
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  17fd142d5ce9b53d8d3a2a7660b2545e
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-5E9gkrEU6WwLqqPGrSWQf0
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
